from flask import Flask, render_template, request, redirect, url_for, send_from_directory, json, jsonify
from werkzeug.utils import secure_filename

from light_face_morph.light_logger import initLogger
from light_face_morph.light_face_morph_handler import handle
import os
from light_face_morph.oos_util import get, put
from light_face_morph.light_util import uuid

# 初始化日志对象
logger = initLogger()
# 执行以下主程序
app = Flask(__name__, template_folder='web/templates', static_folder='web/static')
# 输出中文
app.config['JSON_AS_ASCII'] = False

if not os.path.exists('uploads'):
    os.mkdir('uploads')
app.config['UPLOAD_FOLDER'] = 'uploads/'

app.config['ALLOWED_EXTENSIONS'] = set(['txt', 'ico', 'pdf', 'png', 'jpg', 'jpeg', 'gif'])


def allowed_file(filename):
    return '.' in filename and \
           filename.rsplit('.', 1)[1] in app.config['ALLOWED_EXTENSIONS']


@app.route('/')
def index():
    return render_template('index.html')


@app.route('/upload', methods=['POST'])
def upload():
    logger.info('执行upload')

    uploaded_files = request.files.getlist("file[]")
    file_names = []
    file_paths = []

    try:
        for file in uploaded_files:
            if file and allowed_file(file.filename):
                filename = secure_filename(file.filename)
                file_path = os.path.join(app.config['UPLOAD_FOLDER'], filename)
                file.save(file_path)
                file_names.append(filename)
                file_paths.append(file_path)
                logger.info('filename:' + filename)
                logger.info('file_path:' + file_path)

        video_name = handle(file_paths)
        logger.info(video_name)
    finally:
        for i in file_paths:
            if os.path.exists(i):
                os.remove(i)

    return render_template('upload.html', filenames=file_names, video_name=video_name)


@app.route('/result_data/<filename>')
def result_file(filename):
    logger.info('执行result_file:' + filename)
    return send_from_directory('result_data', filename)


@app.route('/uploads/<filename>')
def uploaded_file(filename):
    logger.info('执行uploaded_file')
    return send_from_directory(app.config['UPLOAD_FOLDER'],
                               filename)


@app.route('/oos', methods=['GET', 'POST'])
def oos():
    oos_param = request.form['oos_param']
    logger.info('oos_param:' + oos_param)

    video_name = uuid()
    try:
        file_list = []
        count = 0
        file_uuid = os.path.join('source_data', uuid())
        for i in eval(oos_param):
            print(i)
            file_name = file_uuid + str(count)
            get(i, file_name)
            count = count + 1
            file_list.append(file_name)

        video_name = handle(file_list)
        logger.info(video_name)
        key = '2aa659457d10a4836fe4/' + video_name
        put('result_data/' + video_name, key)

        result = {
            'code': '1',
            'msg': '调用成功',
            'video_path': key
        }
    finally:
        for i in file_list:
            if os.path.exists(i):
                os.remove(i)
        if os.path.exists('result_data/' + video_name):
            os.remove('result_data/' + video_name)

    return result


@app.route('/test')
def test():
    logger.info('flask方法开始执行')

    handle_data = ['source_data/z1.jpg', 'source_data/3.jpg', 'source_data/4.jpg', 'source_data/5.jpg',
                   'source_data/1.jpg']
    handle(handle_data)

    logger.info("flask方法结束执行")

    result = {
        'code': '1',
        'msg': '调用成功'
    }
    return result


if __name__ == "__main__":
    app.run(
        host='0.0.0.0',
        port=5000,
        debug=True
    )
